summaryrefslogtreecommitdiffstats
path: root/libkdepim/kpimurlrequesterdlg.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /libkdepim/kpimurlrequesterdlg.h
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdepim/kpimurlrequesterdlg.h')
-rw-r--r--libkdepim/kpimurlrequesterdlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libkdepim/kpimurlrequesterdlg.h b/libkdepim/kpimurlrequesterdlg.h
index ef4cc987f..ccbccc88b 100644
--- a/libkdepim/kpimurlrequesterdlg.h
+++ b/libkdepim/kpimurlrequesterdlg.h
@@ -35,11 +35,11 @@ class KDE_EXPORT KPimURLRequesterDlg
*
* @param url This specifies the initial path of the input line.
* @param text The text to be shown on the label.
* @param tqparent The widget the dialog will be centered on initially.
*/
static KURL getURL( const TQString &url = TQString(),
const TQString &text = TQString(),
- TQWidget *tqparent = 0,
+ TQWidget *parent = 0,
const TQString &caption = TQString() );
};
@@ -35,11 +35,11 @@ class KDE_EXPORT KPimURLRequesterDlg
* @param url This specifies the initial path of the input line.
* @param text The text to be shown on the label.
- * @param tqparent The widget the dialog will be centered on initially.
+ * @param parent The widget the dialog will be centered on initially.
*/
static KURL getURL( const TQString &url = TQString(),